/*
 * colours.c - colour configuration.
 *
 * $Id: colours.c 30 2006-02-09 15:29:48Z brendan $
 *
 * NOTE: "colour" is the Australian spelling.
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * COPYRIGHT: Copyright (c) 2006 Brendan Gregg.
 *
 * 29-Jan-2006  Brendan Gregg   Created this
 */

#include <gtk/gtk.h>

#include "dtaz.h"
#include "colours.h"

GdkGC		*c_gc;
GdkColor	c_colours[16];
GdkColor	c_grey;
GdkColor	c_white;
GdkColor	c_blue;
GdkColor	c_red;

enum c_pallet	c_pallet = C_ORIGINAL;
int 		c_colours_max;

/* master colour map */
static GdkColormap	*c_colour_map;

/* original raw colours */
static const int c_raw_0[][3] = {
	{0, 0, 255},
	{255, 0, 255},
	{0, 255, 0},
	{255, 255, 0},
	{255, 100, 0},
	{255, 0, 0}
};

/* greyscale raw colours */
static const int c_raw_1[][3] = {
	{220, 220, 220},
	{200, 200, 200},
	{180, 180, 180},
	{160, 160, 160},
	{140, 140, 140},
	{120, 120, 120},
	{100, 100, 100},
	{80, 80, 80},
	{60, 60, 60},
	{40, 40, 40},
	{20, 20, 20},
	{0, 0, 0},
};

/* scale12 raw colours */
static const int c_raw_2[][3] = {
	{165, 165, 255},
	{90, 90, 255},
	{40, 40, 255},
	{40, 90, 165},
	{40, 165, 90},
	{30, 255, 30},
	{90, 255, 30},
	{165, 255, 30},
	{255, 255, 20},
	{255, 165, 20},
	{255, 90, 10},
	{255, 0, 0}
};

/*
 * colours_set
 *
 * this resets colour definitions. it also reads the global c_pallet,
 * which can be set to different colour pallets,  and sets the global
 * c_colours and c_colours_max based on that.
 */
void
colours_set(GtkWidget *main_window, int first)
{
	int	i;
	int	*colours_raw;

	if (first == TRUE) {

		/* create graphics context, colour_map */
		c_gc = gdk_gc_new(main_window->window);
		gdk_gc_set_line_attributes(c_gc, 2, GDK_LINE_SOLID, 0, 0);
		c_colour_map = gdk_window_get_colormap(main_window->window);

		/* white */
		gdk_color_parse("white", &c_white);
		gdk_colormap_alloc_color(c_colour_map, &c_white, FALSE, TRUE);

		/* red */
		gdk_color_parse("red", &c_red);
		gdk_colormap_alloc_color(c_colour_map, &c_red, FALSE, TRUE);

		/* blue */
		gdk_color_parse("blue", &c_blue);
		gdk_colormap_alloc_color(c_colour_map, &c_blue, FALSE, TRUE);

		/* grey */
		c_grey.red = 222 * 65535/255;
		c_grey.green = 222 * 65535/255;
		c_grey.blue = 222 * 65535/255;
		gdk_colormap_alloc_color(c_colour_map, &c_grey, FALSE, TRUE);
	}

	switch (c_pallet) {
		case C_GREYSCALE:
			colours_raw = (int *)&c_raw_1[0][0];
			c_colours_max = 12;
			break;
		case C_SCALE12:
			colours_raw = (int *)&c_raw_2[0][0];
			c_colours_max = 12;
			break;
		case C_ORIGINAL:
		/* FALLTHROUGH */
		default:
			colours_raw = (int *)&c_raw_0[0][0];
			c_colours_max = 6;
			break;
	}

	/* allocate plot colour scale */
	for (i = 0; i < c_colours_max; i++) {
		/* nothing to see here, move, move along... */
		c_colours[i].red = *(int *)colours_raw++ * 65535/255;
		c_colours[i].green = *(int *)colours_raw++ * 65535/255;
		c_colours[i].blue = *(int *)colours_raw++ * 65535/255;
		gdk_colormap_alloc_color(c_colour_map, &c_colours[i],
		    TRUE, TRUE);
	}
}
