/*
 * dialog.c - message dialogs.
 *
 * $Id: dialog.c 23 2006-02-08 08:32:24Z brendan $
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * COPYRIGHT: Copyright (c) 2006 Brendan Gregg.
 *
 * 29-Jan-2006  Brendan Gregg   Created this
 */

#include <gtk/gtk.h>

#include "dialog.h"

const gchar	*dialog_prtvtoc_msg = "\n"
"An error happened when running the \"prtvtoc\" command.\n"
"This happens if you are not root.\n\n"
"It's no big deal.\n\n"
"It means we are unable to determine the size of the disk.\n"
"So the size will be determined in \"discovery\" mode, where the size\n"
"is set to the largest event seen. If that is a problem, rerun as root.\n";

const gchar	*dialog_stopped_msg = "\n"
"DTrace has abruptly stopped for some reason.\n\n"
"You need to ethier be root, or have the privilege \"dtrace_kernel\".\n\n"
"An example of root temporarily giving dtaz processes this privilege is,\n"
"	# ppriv -s A+dtrace_kernel `pgrep dtaz`\n"
"assuming only 1 dtaz is running.\n";

const gchar	*dialog_about_msg = "\n"
"This is an alpha version of DTraceTazTool, and is under development.\n\n"
"The original TAZ Tool by Richard McDougall used TNF tracing. (TNF tracing\n"
"was made available in Solaris 2.5). The TAZ Tool website is,\n\n"
"	http://www.solarisinternals.com/si/tools/taz/index.php\n\n"
"This version uses DTrace. (DTrace has been available since Solaris 10).\n\n"
"For other disk analysis tools, see the DTraceToolkit,\n\n"
"	http://www.opensolaris.org/os/community/dtrace/dtracetoolkit\n\n"
"DTraceTazTool was written by Brendan Gregg [Sydney, Australia]\n";

const gchar	*dialog_slice_2_msg = "\n"
"Slice 2 does not trace the whole disk.\n\n"
"It is in the list because some people use slice 2 as a regular slice,\n"
"which seems odd considering SMI disk labels; however it will become\n"
"commonplace once EFI disk labels are more prolific.\n\n"
"So if slice 2 is mounted or is being used directly, you'll see activity.\n"
"If not, the plot will flatline.\n";

void
dialog_message(GtkWidget *window, const gchar *title, const gchar *message)
{
	GtkWidget	*dialog;
	GtkWidget	*label;

	/* create the widgets */
	dialog = gtk_dialog_new_with_buttons(title,
	    GTK_WINDOW(window),
	    GTK_DIALOG_DESTROY_WITH_PARENT,
	    GTK_STOCK_OK,
	    GTK_RESPONSE_NONE,
	    NULL);
	label = gtk_label_new(message);

	/* destroy box on response */
	g_signal_connect_swapped(dialog, "response",
	    G_CALLBACK(gtk_widget_destroy), dialog);

	/* add label */
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);

	/* show */
	gtk_widget_show_all(dialog);
}

void
dialog_about(gpointer data, guint action, GtkWidget *menu)
{
	GtkWidget	*dialog;
	GtkWidget	*view;
	GtkTextBuffer	*buffer;

	/* create the widgets */
	dialog = gtk_dialog_new_with_buttons("About",
	    GTK_WINDOW_TOPLEVEL,
	    GTK_DIALOG_DESTROY_WITH_PARENT,
	    GTK_STOCK_OK,
	    GTK_RESPONSE_NONE,
	    NULL);

	/* create text box */
	view = gtk_text_view_new();
	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(view));
	gtk_text_buffer_set_text(GTK_TEXT_BUFFER(buffer),
	    dialog_about_msg, -1);

	/* destroy box on response */
	g_signal_connect_swapped(dialog, "response",
	    G_CALLBACK(gtk_widget_destroy), dialog);

	/* add view */
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), view);

	/* show */
	gtk_widget_show_all(dialog);
}
