/*
 * dtaz.h - dtaz header.
 *
 * $Id: dtaz.h 28 2006-02-09 12:34:42Z brendan $
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * COPYRIGHT: Copyright (c) 2006 Brendan Gregg.
 *
 * 29-Jan-2006  Brendan Gregg   Created this
 */

#ifndef DTAZ_H
#define	DTAZ_H

#include <stdio.h>
#include <sys/types.h>

/* routine */
#define	BUF_SIZE	8192
#define	LINE_LEN	256
#define	DEBUG		0

/*
 * Minimum and initial geometry
 */
#define	DT_PLOT_MIN_X	400
#define	DT_PLOT_MIN_Y	200
#define	DT_PLOT_MAX_X	2048
#define	DT_PLOT_MAX_Y	1024
#define	DT_SEEK_MIN_X	400
#define	DT_SEEK_MIN_Y	75
#define	DT_PLOT_INI_X	500
#define	DT_PLOT_INI_Y	300
#define	DT_SEEK_INI_X	500
#define	DT_SEEK_INI_Y	100
#define	DT_PLOT_MAX_DEF	20000
#define	DT_SAVE_VERSION	1

/*
 * GTK Widgets
 *
 * all globals have a "dt_" prefix
 */
extern GtkWidget	*dt_main_window;	/* main window widget */
extern GtkWidget	*dt_main_table;		/* main table widget */
extern GtkWidget	*dt_plot_da;		/* plot drawing area */
extern GtkWidget	*dt_plot_table;		/* plot table for labels */
extern GtkWidget	*dt_plot_label[3];	/* plot labels */
extern GtkWidget	*dt_seek_da;		/* seek drawing area */
extern GtkWidget	*dt_seek_table;		/* seek table for labels */
extern GtkWidget	*dt_seek_label[3];	/* seek labels */
extern GtkWidget	*dt_main_menu;		/* main menu */
extern GtkWidget	*dt_status;		/* status bar */
extern GtkWidget	*dt_top_table;		/* top table */
extern GtkWidget	*dt_selector;		/* disk selector */
extern GtkWidget	*dt_start_b;		/* start tracing button */
extern GtkWidget	*dt_stop_b;		/* stop tracing button */

/*
 * Globals
 */
extern int	dt_resolution;			/* pixel resolution */
extern uint64_t	dt_time;			/* current time (ms) */
extern int	dt_current_x;			/* current x loc pxl/res */
extern int64_t	dt_plot_max_raw;		/* maximum plot y RAW */
extern int	dt_seek_last_ym;		/* current seek "max" y pxl */
extern int	dt_seek_last_ya;		/* current seek "avg" y pxl */
extern int64_t	dt_seek_last_raw;		/* last raw seek loc */
extern int64_t	dt_seek_max_raw;		/* max raw seek loc */
extern int64_t	dt_seek_sum_raw;		/* sum of raw seek locs */
extern int	dt_seek_count;			/* number of seeks */
extern int	dt_delay;			/* timeout delay ms */
extern int	dt_update;			/* screen update ms */
extern int	dt_update_counter;		/* screen update counter */
extern int	dt_colour_factor;		/* scaling for the colours */
extern int	dt_dtrace_check;		/* dtrace pulse counter */
extern int	dt_plot_resized;		/* plot resized */
extern int	dt_plot_exposed;		/* plot exposed */

/* entry for storing seek plot data */
typedef struct dt_seek_entry {
	uint32_t avg;
	uint32_t max;
} dt_seek_entry_t;

/* plot and seek canvas */
extern uint16_t		dt_plot_canvas[DT_PLOT_MAX_X][DT_PLOT_MAX_Y];
extern dt_seek_entry_t	dt_seek_canvas[DT_PLOT_MAX_X];

/* plot buckets */
extern int	dt_plot_buckets[DT_PLOT_MAX_Y];

/*
 * Scale state
 *
 * this is whether we know the size of the disk slice, or if we
 * are determining it on the fly in "discovery" mode.
 */
enum dt_scale {
	DT_SCALE_INITIAL,
	DT_SCALE_KNOWN,
	DT_SCALE_DISCOVERY,
	DT_SCALE_ERR
};
extern enum dt_scale	dt_scale;

/* functions */
extern void	start_tracing(void);
extern void	stop_tracing(void);
extern void	new_screen(void);
extern void	update_options_info(void);

#endif /* DTAZ_H */
